conz.prep just
run flux on the result returned by conz.prep and
get flux rates in an easy to interpret table including quality flags. Plot
diagnostic plots as pdf per factor level to a folder or simply to the
screen.Forbrich I, Kutzbach L, Hormann A, Wilmking M (2010) A comparison of linear and exponential regression for estimating diffusive CH4 fluxes by closed- chambers in peatlands. Soil Biology and Biochemistry 42: 507-515.
HMR for a different approach to flux rate estimation from chamber data (aditionally it is meant for static chamber data).