conz.prepinspect(x, what, sustain = NULL, retain = FALSE)conz.prep containing tables with chamber measurement data.x that ought to be inspected/altered. For inspection either give a numeric vector with the indices of the tables or a character vector with the names of the entries in x. For altex can be quite complex. However, a certain part may be the same for all the tables you want to inspect/alter. In this case just give this part here and skip it in what.x by giving a list structure to what, shall the original data tables be returned as well? Defaults to FALSE.x. In case retain = TRUE the original tables are appended to x. The respective list item is tables.orig.flux estimation and then turn to inspect for having a closer look at the data or to delete some concentration measurements for further estimations.flux, fluxes, conz.prep,
(also for examples)